# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version   | Supported          |
| --------- | ------------------ |
| 0.2.0     | :white_check_mark: |
| 0.1.9     | :x:                |
| 0.1.8     | :x:                |
| 0.1.7     | :x:                |
| 0.1.6     | :x:                |
| 0.1.5     | :x:                |
| < 0.1.4   | :x:                |

## Reporting a Vulnerability

Use this section to tell people how to report a vulnerability.

Tell them where to go, how often they can expect to get an update on a
reported vulnerability, what to expect if the vulnerability is accepted or
declined, etc.
